Create an S3 object that sets all the required data needed by energyGOFdist to execute the energy goodness-of-fit test against a F distribution. Only simple tests are supported.
f_dist(df1 = 3, df2 = 3)S3 data object containing the following fields.
name: String
composite_p: Composite predicate. TRUE if test is composite.
par: Distribution parameters, list of the formals.
sampler_par: Distribution parameters used for the calculation of energy
statistic. These may be different than par.
par_domain: Function used to ensure par and sampler_par are valid for
this distribution
support: Function to check that data x can be tested against y
sampler: Function used for rng by boot::boot()
EYY: Function to compute \(E|Y-Y'|\) (or \(E|Y-Y'|^{pow}\), for the
generalized test.)
EXYhat: Function to compute \(\frac{1}{n} \sum_i E|x_i - Y|\) (or
\(\frac{1}{n} \sum_i E|x_i - Y|^{pow}\)), where Y is distributed according
to y and x is the data under test (which is passed in egof.test or egofd).
xform: Function that may be used to transform x. Only available in certain
distribution objects.
statistic: Function that returns a list of maximum likelihood estimates.
Only available in certain distribution objects.
notes: Distribution specific messages. Only used in certain distribution
objects.
Note: Some distributions do not have notes, xform, and statistic fields. This is because either a composite test is not implemented, or because a data transformation is not needed.
Positive.
Must be greater than 2.
John T. Haman
d <- f_dist(3, 3)
egofd(rf(10, 3, 3), d, 0)
Run the code above in your browser using DataLab