Learn R Programming

energyGOF (version 0.1)

lognormal_dist: Create a lognormal distribution object for energy testing

Description

Create an S3 object that sets all the required data needed by energyGOFdist to execute the energy goodness-of-fit test against a lognormal distribution. If meanlog and sdlog are both NULL, a composite test is performed.

Usage

lognormal_dist(meanlog = NULL, sdlog = NULL)

Value

S3 data object containing the following fields.

  • name: String

  • composite_p: Composite predicate. TRUE if test is composite.

  • par: Distribution parameters, list of the formals.

  • sampler_par: Distribution parameters used for the calculation of energy statistic. These may be different than par.

  • par_domain: Function used to ensure par and sampler_par are valid for this distribution

  • support: Function to check that data x can be tested against y

  • sampler: Function used for rng by boot::boot()

  • EYY: Function to compute \(E|Y-Y'|\) (or \(E|Y-Y'|^{pow}\), for the generalized test.)

  • EXYhat: Function to compute \(\frac{1}{n} \sum_i E|x_i - Y|\) (or \(\frac{1}{n} \sum_i E|x_i - Y|^{pow}\)), where Y is distributed according to y and x is the data under test (which is passed in egof.test or egofd).

  • xform: Function that may be used to transform x. Only available in certain distribution objects.

  • statistic: Function that returns a list of maximum likelihood estimates. Only available in certain distribution objects.

  • notes: Distribution specific messages. Only used in certain distribution objects.

Note: Some distributions do not have notes, xform, and statistic fields. This is because either a composite test is not implemented, or because a data transformation is not needed.

Arguments

meanlog

NULL or as in rlnorm(), must be length 1.

sdlog

NULL or as in rlnorm(), must be length 1.

d <- lognormal_dist(0, 1) x <- d$sampler(10, d$par)

egofd(x, d, 0)

Author

John T. Haman